import argparse
import os
from .initializer import Initializer
from excel_builder import build_excel

def main() -> None:
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawTextHelpFormatter,
        description="""
This is a tool to convert markdown file to excel.
""",
        epilog="""
== Example Use Case ==

# Initialize the directory
% mael init .
# Create some markdown files in the directory 
# Build the Excel file
% mael build .
"""
    )
    subparsers = parser.add_subparsers(dest='command')
    # parser for init command
    parser_init = subparsers.add_parser('init', help='Generate config files')
    parser_init.add_argument('directory', default=os.getcwd(), help='Directory to be initialized.')
    # parser for build command
    parser_build = subparsers.add_parser('build', help='Build Excel from markdown files')
    parser_build.add_argument('directory', default=os.getcwd(), help='Directory which holds markdown files.')

    args = parser.parse_args()

    if args.directory:
        if os.path.isabs(args.directory):
            target_dir = args.directory
        else:
            target_dir = os.path.join(os.getcwd(), args.directory)
    else:
        target_dir = os.getcwd()

    if args.command == 'init':
        # create init file
        i = Initializer(target_dir)
        i.initialize()
    elif args.command == 'build':
        # read the directory
        build_excel(target_dir)

# TODO:
#   * font configuration



import os
import re
import shutil


class Initializer:
    def __init__(self, dir_path):
        self.dir_path = dir_path

    def initialize(self):
        dir_path = self.dir_path
        print(f'initialize {dir_path}')
        while True:
            answer = input('Do you use template? [y/n]: ')
            answer = answer.lower()
            if answer == 'y':
                templates = {
                    0: 'None',
                    1: 'Test case'
                }
                while True:
                    template_answer = input(
                        "\n".join([
                            "Which template do you use?\n",
                            *[f'{k}: {v}' for k, v in templates.items()],
                            '\nType number: '
                        ])
                    )
                    if not re.match(r'\d', template_answer):
                        continue
                    template_answer = int(template_answer)
                    if template_answer in templates:
                        break
                break
            elif answer == 'n':
                break

        file_path = os.path.abspath(__file__)
        template_path = os.path.join(
            os.path.dirname(file_path),
            'templates',
            templates[template_answer].lower().replace(' ', '_')
        )

        if not os.path.exists(dir_path):
            os.mkdir(dir_path)
        shutil.copytree(template_path, dir_path, dirs_exist_ok=True)

